## Tutorial using Merlin
In this folder we provide a baseline recommender algorithms using the [Merlin framework](https://github.com/NVIDIA-Merlin/).
It provides two retrieval models: **Matrix Factorization** and **Two-Tower architecture**.  

You have two options to execute them:
- [Notebook](evalrs_tutorial_retrieval_models_with_merlin.ipynb)
- [Python Script](evalrs_tutorial_retrieval_models_with_merlin_script.py)

### Install dependencies
Before running the code, you need to install a few additional dependendencies with

```bash
pip install -r notebooks/merlin_tutorial/requirements.txt
```